IntegerDomain
=============

.. currentmodule:: pqp.data

.. autoclass:: IntegerDomain
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~IntegerDomain.check_int
      ~IntegerDomain.describe_assumptions
      ~IntegerDomain.get_cardinality
      ~IntegerDomain.get_values

   .. rubric:: Methods Documentation

   .. automethod:: check_int
   .. automethod:: describe_assumptions
   .. automethod:: get_cardinality
   .. automethod:: get_values
